package br.uff.commerce.requestprocessing;

import java.util.HashMap;
import java.util.Map;

import br.uff.commerce.domain.customer.EditCustomerRequest;
import br.uff.commerce.domain.product.EditProductRequest;
import br.uff.commerce.request.Request;

/**
 * Factory parametrizado e Singleton.
 *
 */
public class RequestFactory
{
	private static RequestFactory soleInstance = null;
	
	public static RequestFactory getSoleInstance()
	{
		if (RequestFactory.soleInstance == null)
			RequestFactory.soleInstance = new RequestFactory();
		
		return RequestFactory.soleInstance;
	}
	
	private Map<String, Request> pool;
	
	private RequestFactory() 
	{
		this.pool = new HashMap<String, Request>();
	}
	
	public Request createRequest(String requestName)
	{
		if (requestName == null || requestName.trim().isEmpty())
			throw new IllegalArgumentException("Request name is mandatory.");
		
		Request result = this.pool.get(requestName);
		
		if (result == null)
		{
			if (requestName.equals(EditProductRequest.NAME))
				result = new EditProductRequest();
			else if (requestName.equals(EditCustomerRequest.NAME))
				result = new EditCustomerRequest();
			else 
				throw new IllegalArgumentException(
						"Request object not found for "+ requestName);
			
			this.pool.put(requestName, result);
			
		}
		
		return result;
	}
	
}
